# Generated by Django 2.2.6 on 2019-10-14 16:01

from django.db import migrations, models

import richie.apps.core.fields.multiselect


class Migration(migrations.Migration):

    dependencies = [("courses", "0008_auto_20191001_1212")]

    operations = [
        migrations.AddField(
            model_name="coursepluginmodel",
            name="variant",
            field=models.CharField(
                blank=True,
                choices=[(None, "Default")],
                help_text="Optional glimpse variant for a custom look.",
                max_length=50,
                null=True,
                verbose_name="variant",
            ),
        )
    ]
