(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[88856],{88856:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"今年",1:"明年",future:{other:"{0}年后"},past:{other:"{0}年前"},"-1":"去年"},"year-short":{0:"今年",1:"明年",future:{other:"{0}年后"},past:{other:"{0}年前"},"-1":"去年"},"year-narrow":{0:"今年",1:"明年",future:{other:"{0}年后"},past:{other:"{0}年前"},"-1":"去年"},quarter:{0:"本季度",1:"下季度",future:{other:"{0}个季度后"},past:{other:"{0}个季度前"},"-1":"上季度"},"quarter-short":{0:"本季度",1:"下季度",future:{other:"{0}个季度后"},past:{other:"{0}个季度前"},"-1":"上季度"},"quarter-narrow":{0:"本季度",1:"下季度",future:{other:"{0}个季度后"},past:{other:"{0}个季度前"},"-1":"上季度"},month:{0:"本月",1:"下个月",future:{other:"{0}个月后"},past:{other:"{0}个月前"},"-1":"上个月"},"month-short":{0:"本月",1:"下个月",future:{other:"{0}个月后"},past:{other:"{0}个月前"},"-1":"上个月"},"month-narrow":{0:"本月",1:"下个月",future:{other:"{0}个月后"},past:{other:"{0}个月前"},"-1":"上个月"},week:{0:"本周",1:"下周",future:{other:"{0}周后"},past:{other:"{0}周前"},"-1":"上周"},"week-short":{0:"本周",1:"下周",future:{other:"{0}周后"},past:{other:"{0}周前"},"-1":"上周"},"week-narrow":{0:"本周",1:"下周",future:{other:"{0}周后"},past:{other:"{0}周前"},"-1":"上周"},day:{0:"今天",1:"明天",2:"后天",future:{other:"{0}天后"},past:{other:"{0}天前"},"-2":"前天","-1":"昨天"},"day-short":{0:"今天",1:"明天",2:"后天",future:{other:"{0}天后"},past:{other:"{0}天前"},"-2":"前天","-1":"昨天"},"day-narrow":{0:"今天",1:"明天",2:"后天",future:{other:"{0}天后"},past:{other:"{0}天前"},"-2":"前天","-1":"昨天"},hour:{0:"这一时间 / 此时",future:{other:"{0}小时后"},past:{other:"{0}小时前"}},"hour-short":{0:"这一时间 / 此时",future:{other:"{0}小时后"},past:{other:"{0}小时前"}},"hour-narrow":{0:"这一时间 / 此时",future:{other:"{0}小时后"},past:{other:"{0}小时前"}},minute:{0:"此刻",future:{other:"{0}分钟后"},past:{other:"{0}分钟前"}},"minute-short":{0:"此刻",future:{other:"{0}分钟后"},past:{other:"{0}分钟前"}},"minute-narrow":{0:"此刻",future:{other:"{0}分钟后"},past:{other:"{0}分钟前"}},second:{0:"现在",future:{other:"{0}秒钟后"},past:{other:"{0}秒钟前"}},"second-short":{0:"现在",future:{other:"{0}秒后"},past:{other:"{0}秒前"}},"second-narrow":{0:"现在",future:{other:"{0}秒后"},past:{other:"{0}秒前"}}},locale:"zh-Hans"})}}]);
//# sourceMappingURL=88856.f07cb65ce0230ab5c06e.index.js.map