(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[47375],{47375:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"हें वर्स",1:"फुडलें वर्स",future:{other:"{0} वर्सांनीं"},past:{other:"{0} वर्सां आदीं"},"-1":"फाटलें वर्स"},"year-short":{0:"हें वर्स",1:"फुडलें वर्स",future:{other:"{0} वर्सांनीं"},past:{other:"{0} वर्स आदीं"},"-1":"फाटलें वर्स"},"year-narrow":{0:"हें वर्स",1:"फुडलें वर्स",future:{other:"{0} वर्सांनीं"},past:{other:"{0} वर्स आदीं"},"-1":"फाटलें वर्स"},quarter:{0:"हो त्रैमासीक",1:"फुडलो त्रैमासीक",future:{other:"{0} त्रैमासीकांत"},past:{other:"{0} त्रैमासीकां आदीं"},"-1":"फाटलो त्रैमासीक"},"quarter-short":{0:"हो त्रैमासीक",1:"फुडलो त्रैमासीक",future:{other:"{0} त्रैमासीकांत"},past:{other:"{0} त्रैमासीकां आदीं"},"-1":"फाटलो त्रैमासीक"},"quarter-narrow":{0:"हो त्रैमासीक",1:"फुडलो त्रैमासीक",future:{other:"{0} त्रैमासीकांत"},past:{other:"{0} त्रैमासीकां आदीं"},"-1":"फाटलो त्रैमासीक"},month:{0:"हो म्हयनो",1:"फुडलो म्हयनो",future:{other:"{0} म्हयन्यानीं"},past:{other:"{0} म्हयन्यां आदीं"},"-1":"फाटलो म्हयनो"},"month-short":{0:"हो म्हयनो",1:"फुडलो म्हयनो",future:{other:"{0} म्हयन्यानीं"},past:{other:"{0} म्हयन्यां आदीं"},"-1":"फाटलो म्हयनो"},"month-narrow":{0:"हो म्हयनो",1:"फुडलो म्हयनो",future:{other:"{0} म्हयन्यानीं"},past:{other:"{0} म्हयन्यां आदीं"},"-1":"फाटलो म्हयनो"},week:{0:"हो सप्तक",1:"फुडलो सप्तक",future:{other:"{0} सप्तकांनीं"},past:{other:"{0} सप्तकां आदीं"},"-1":"निमाणो सप्तक"},"week-short":{0:"हो सप्तक",1:"फुडलो सप्तक",future:{other:"{0} सप्तकांनीं"},past:{other:"{0} सप्तकां आदीं"},"-1":"निमाणो सप्तक"},"week-narrow":{0:"हो सप्तक",1:"फुडलो सप्तक",future:{other:"{0} सप्तकांनीं"},past:{other:"{0} सप्त. आदीं"},"-1":"निमाणो सप्तक"},day:{0:"आयज",1:"फाल्यां",future:{other:"{0} दिसानीं"},past:{other:"{0} दीस आदीं"},"-1":"काल"},"day-short":{0:"आयज",1:"फाल्यां",future:{other:"{0} दिसानीं"},past:{other:"{0} दीस आदीं"},"-1":"काल"},"day-narrow":{0:"आयज",1:"फाल्यां",future:{other:"{0} दिसानीं"},past:{other:"{0} दीस आदीं"},"-1":"काल"},hour:{0:"हें वर",future:{other:"{0} वरांनीं"},past:{other:"{0} वरा आदीं"}},"hour-short":{0:"हें वर",future:{other:"{0} वरांनीं"},past:{other:"{0} वरा आदीं"}},"hour-narrow":{0:"हें वर",future:{other:"{0} वरांनीं"},past:{other:"{0} वरा आदीं"}},minute:{0:"हें मिनीट",future:{other:"{0} मिन्टां"},past:{other:"{0} मिन्टां आदीं"}},"minute-short":{0:"हें मिनीट",future:{other:"{0} मिन्टां"},past:{other:"{0} मिन्टां आदीं"}},"minute-narrow":{0:"हें मिनीट",future:{other:"{0} मिन्टां"},past:{other:"{0} मिन्टां आदीं"}},second:{0:"आतां",future:{other:"{0} सेकंदानीं"},past:{other:"{0} सेकंद आदीं"}},"second-short":{0:"आतां",future:{other:"{0} सेकंदानीं"},past:{other:"{0} से. आदीं"}},"second-narrow":{0:"आतां",future:{other:"{0} सेकंदानीं"},past:{other:"{0} से. आदीं"}}},locale:"kok"})}}]);
//# sourceMappingURL=47375.f07cb65ce0230ab5c06e.index.js.map