{% load cms_tags i18n %}
{% spaceless %}
{% if target_page %}
    {% with blogpost=target_page.blogpost %}
      {% include "courses/cms/fragment_blogpost_glimpse.html" %}
    {% endwith %}
{% endif %}
{% endspaceless %}
