# Generated by Django 3.1.3 on 2020-11-18 10:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("courses", "0019_auto_20201117_1004"),
    ]

    operations = [
        migrations.AlterField(
            model_name="categorypluginmodel",
            name="variant",
            field=models.CharField(
                blank=True,
                choices=[
                    (None, "Inherit"),
                    ("glimpse", "Default"),
                    ("badge", "Badge"),
                    ("tag", "Tag"),
                ],
                help_text="Optional glimpse variant for a custom look.",
                max_length=50,
                null=True,
                verbose_name="variant",
            ),
        ),
    ]
