# Generated by Django 3.1.3 on 2020-11-23 10:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("courses", "0022_auto_20201202_convert_course_runs_to_simple_models"),
    ]

    operations = [
        migrations.AlterField(
            model_name="courserun",
            name="direct_course",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="runs",
                to="courses.course",
            ),
        ),
        migrations.RemoveField(
            model_name="courserun",
            name="extended_object",
        ),
        migrations.RemoveField(
            model_name="courserun",
            name="public_extension",
        ),
    ]
