(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[83400],{83400:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"Dís yiẹ",1:"Nẹ́st yiẹ",future:{one:"fọ {0} yiẹ wé de kọm",other:"fọ {0} yiẹ wé de kọm"},past:{one:"{0} yiẹ wé dọ́n pas",other:"{0} yiẹ wé dọ́n pas"},"-1":"Lást yiẹ"},"year-short":{0:"Dís yiẹ",1:"Nẹ́st yiẹ",future:{one:"fọ {0} yiẹ wé de kọm",other:"fọ {0} yiẹ wé de kọm"},past:{one:"{0} yiẹ wé dọ́n pas",other:"{0} yiẹ wé dọ́n pas"},"-1":"Lást yiẹ"},"year-narrow":{0:"Dís yiẹ",1:"Nẹ́st yiẹ",future:{one:"fọ {0} yiẹ wé de kọm",other:"fọ {0} yiẹ wé de kọm"},past:{one:"{0} yiẹ wé dọ́n pas",other:"{0} yiẹ wé dọ́n pas"},"-1":"Lást yiẹ"},quarter:{0:"Dís kwọ́ta",1:"Nẹ́st kwọ́ta",future:{one:"fọ {0} kwọ́ta wé de kọm",other:"fọ {0} kwọ́ta wé de kọm"},past:{one:"{0} kwọ́ta wé dọ́n pas",other:"{0} kwọ́ta wé dọ́n pas"},"-1":"Lást kwọ́ta"},"quarter-short":{0:"Dís kwọ́ta",1:"Nẹ́st kwọ́ta",future:{one:"fọ {0} kwọ́ta wé de kọm",other:"fọ {0} kwọ́ta wé de kọm"},past:{one:"{0} kwọ́ta wé dọ́n pas",other:"{0} kwọ́ta wé dọ́n pas"},"-1":"Lást kwọ́ta"},"quarter-narrow":{0:"Dís kwọ́ta",1:"Nẹ́st kwọ́ta",future:{one:"fọ {0} kwọ́ta wé de kọm",other:"fọ {0} kwọ́ta wé de kọm"},past:{one:"{0} kwọ́ta wé dọ́n pas",other:"{0} kwọ́ta wé dọ́n pas"},"-1":"Lást kwọ́ta"},month:{0:"Dís mọnt",1:"Nẹ́st mọnt",future:{one:"Fọ {0}mọnt wé de kọm",other:"Fọ {0}mọnt wé de kọm"},past:{one:"{0} mọnt wé dọ́n pas",other:"{0} mọnt wé dọ́n pas"},"-1":"Lást mọnt"},"month-short":{0:"Dís mọnt",1:"Nẹ́st mọnt",future:{one:"Fọ {0}mọnt wé de kọm",other:"Fọ {0}mọnt wé de kọm"},past:{one:"{0} mọnt wé dọ́n pas",other:"{0} mọnt wé dọ́n pas"},"-1":"Lást mọnt"},"month-narrow":{0:"Dís mọnt",1:"Nẹ́st mọnt",future:{one:"Fọ {0}mọnt wé de kọm",other:"Fọ {0}mọnt wé de kọm"},past:{one:"{0} mọnt wé dọ́n pas",other:"{0} mọnt wé dọ́n pas"},"-1":"Lást mọnt"},week:{0:"Dís wik",1:"Nẹ́st wik",future:{one:"Fọ {0}wik wé de kọm",other:"Fọ {0}wik wé de kọm"},past:{one:"{0} wik wé dọ́n pas",other:"{0} wik wé dọ́n pas"},"-1":"Lást wik"},"week-short":{0:"Dís wik",1:"Nẹ́st wik",future:{one:"Fọ {0}wik wé de kọm",other:"Fọ {0}wik wé de kọm"},past:{one:"{0} wik wé dọ́n pas",other:"{0} wik wé dọ́n pas"},"-1":"Lást wik"},"week-narrow":{0:"Dís wik",1:"Nẹ́st wik",future:{one:"Fọ {0}wik wé de kọm",other:"Fọ {0}wik wé de kọm"},past:{one:"{0} wik wé dọ́n pas",other:"{0} wik wé dọ́n pas"},"-1":"Lást wik"},day:{0:"Todè",1:"Tumọ́ro",future:{one:"Fọ {0}dè wé de kọm",other:"Fọ {0}dè wé de kọm"},past:{one:"{0} dè wé dọ́n pas",other:"{0} dè wé dọ́n pas"},"-1":"Yẹ́stadè"},"day-short":{0:"Todè",1:"Tumọ́ro",future:{one:"Fọ {0}dè wé de kọm",other:"Fọ {0}dè wé de kọm"},past:{one:"{0} dè wé dọ́n pas",other:"{0} dè wé dọ́n pas"},"-1":"Yẹ́stadè"},"day-narrow":{0:"Todè",1:"Tumọ́ro",future:{one:"Fọ {0}dè wé de kọm",other:"Fọ {0}dè wé de kọm"},past:{one:"{0} dè wé dọ́n pas",other:"{0} dè wé dọ́n pas"},"-1":"Yẹ́stadè"},hour:{0:"Dís áwa",future:{one:"Fọ {0} áwa wé de kọm",other:"Fọ {0} áwa wé de kọm"},past:{one:"{0} áwa wé dọ́n pas",other:"{0} áwa wé dọ́n pas"}},"hour-short":{0:"Dís áwa",future:{one:"Fọ {0} áwa wé de kọm",other:"Fọ {0} áwa wé de kọm"},past:{one:"{0} áwa wé dọ́n pas",other:"{0} áwa wé dọ́n pas"}},"hour-narrow":{0:"Dís áwa",future:{one:"Fọ {0} áwa wé de kọm",other:"Fọ {0} áwa wé de kọm"},past:{one:"Fọ {0} áwa wé de kọm",other:"Fọ {0} áwa wé de kọm"}},minute:{0:"Dís mínit",future:{one:"Fọ {0} mínit wé de kọm",other:"Fọ {0} mínit wé de kọm"},past:{one:"{0} mínit wé dọ́n pas",other:"{0} mínit wé dọ́n pas"}},"minute-short":{0:"Dís mínit",future:{one:"Fọ {0} mínit wé de kọm",other:"Fọ {0} mínit wé de kọm"},past:{one:"{0} mínit wé dọ́n pas",other:"{0} mínit wé dọ́n pas"}},"minute-narrow":{0:"Dís mínit",future:{one:"Fọ {0} mínit wé de kọm",other:"Fọ {0} mínit wé de kọm"},past:{one:"{0} mínit wé dọ́n pas",other:"{0} mínit wé dọ́n pas"}},second:{0:"nau",future:{one:"Fọ {0} Sẹ́kọn",other:"Fọ {0} Sẹ́kọn"},past:{one:"{0} sẹ́kọn wé dọ́n pas",other:"{0} sẹ́kọn wé dọ́n pas"}},"second-short":{0:"nau",future:{one:"Fọ {0} Sẹ́kọn",other:"Fọ {0} Sẹ́kọn"},past:{one:"{0} sẹ́kọn wé dọ́n pas",other:"{0} sẹ́kọn wé dọ́n pas"}},"second-narrow":{0:"nau",future:{one:"Fọ {0} Sẹ́kọn",other:"Fọ {0} Sẹ́kọn"},past:{one:"{0} sẹ́kọn wé dọ́n pas",other:"{0} sẹ́kọn wé dọ́n pas"}}},locale:"pcm"})}}]);
//# sourceMappingURL=83400.f07cb65ce0230ab5c06e.index.js.map