(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[19068],{19068:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"ove godine",1:"sljedeće godine",future:{one:"za {0} godinu",few:"za {0} godine",other:"za {0} godina"},past:{one:"prije {0} godine",few:"prije {0} godine",other:"prije {0} godina"},"-1":"prošle godine"},"year-short":{0:"ove god.",1:"sljedeće god.",future:{one:"za {0} god.",few:"za {0} god.",other:"za {0} god."},past:{one:"prije {0} god.",few:"prije {0} god.",other:"prije {0} god."},"-1":"prošle god."},"year-narrow":{0:"ove g.",1:"sljedeće g.",future:{one:"za {0} g.",few:"za {0} g.",other:"za {0} g."},past:{one:"prije {0} g.",few:"prije {0} g.",other:"prije {0} g."},"-1":"prošle g."},quarter:{0:"ovog kvartala",1:"sljedećeg kvartala",future:{one:"za {0} kvartal",few:"za {0} kvartala",other:"za {0} kvartala"},past:{one:"prije {0} kvartala",few:"prije {0} kvartala",other:"prije {0} kvartala"},"-1":"prošlog kvartala"},"quarter-short":{0:"ovog kvartala",1:"sledećeg kvartala",future:{one:"za {0} kv.",few:"za {0} kv.",other:"za {0} kv."},past:{one:"prije {0} kv.",few:"prije {0} kv.",other:"prije {0} kv."},"-1":"prošlog kvartala"},"quarter-narrow":{0:"ovog kvartala",1:"sledećeg kvartala",future:{one:"za {0} kv.",few:"za {0} kv.",other:"za {0} kv."},past:{one:"prije {0} kv.",few:"prije {0} kv.",other:"prije {0} kv."},"-1":"prošlog kvartala"},month:{0:"ovog mjeseca",1:"sljedećeg mjeseca",future:{one:"za {0} mjesec",few:"za {0} mjeseca",other:"za {0} mjeseci"},past:{one:"prije {0} mjeseca",few:"prije {0} mjeseca",other:"prije {0} mjeseci"},"-1":"prošlog mjeseca"},"month-short":{0:"ovog mjes.",1:"sljedećeg mjes.",future:{one:"za {0} mjes.",few:"za {0} mjes.",other:"za {0} mjes."},past:{one:"prije {0} mjes.",few:"prije {0} mjes.",other:"prije {0} mjes."},"-1":"prošlog mjes."},"month-narrow":{0:"ovog m.",1:"sljedećeg m.",future:{one:"za {0} m.",few:"za {0} m.",other:"za {0} m."},past:{one:"prije {0} m.",few:"prije {0} m.",other:"prije {0} m."},"-1":"prošlog m."},week:{0:"ove nedjelje",1:"naredne nedelje",future:{one:"za {0} nedjelju",few:"za {0} nedjelje",other:"za {0} nedjelja"},past:{one:"prije {0} nedjelje",few:"prije {0} nedjelje",other:"prije {0} nedjelja"},"-1":"prethodne nedelje"},"week-short":{0:"ove ned.",1:"sledeće ned.",future:{one:"za {0} ned.",few:"za {0} ned.",other:"za {0} ned."},past:{one:"prije {0} ned.",few:"prije {0} ned.",other:"prije {0} ned."},"-1":"prošle ned."},"week-narrow":{0:"ove n.",1:"sljedeće n.",future:{one:"za {0} n.",few:"za {0} n.",other:"za {0} n."},past:{one:"prije {0} n.",few:"prije {0} n.",other:"prije {0} n."},"-1":"prošle n."},day:{0:"danas",1:"sutra",2:"prekosutra",future:{one:"za {0} dan",few:"za {0} dana",other:"za {0} dana"},past:{one:"prije {0} dana",few:"prije {0} dana",other:"prije {0} dana"},"-2":"prekjuče","-1":"juče"},"day-short":{0:"danas",1:"sutra",2:"prekosutra",future:{one:"za {0} d.",few:"za {0} d.",other:"za {0} d."},past:{one:"prije {0} d.",few:"prije {0} d.",other:"prije {0} d."},"-2":"prekjuče","-1":"juče"},"day-narrow":{0:"danas",1:"sutra",2:"prekosutra",future:{one:"za {0} d.",few:"za {0} d.",other:"za {0} d."},past:{one:"prije {0} d.",few:"prije {0} d.",other:"prije {0} d."},"-2":"prekjuče","-1":"juče"},hour:{0:"ovog sata",future:{one:"za {0} sat",few:"za {0} sata",other:"za {0} sati"},past:{one:"prije {0} sata",few:"prije {0} sata",other:"prije {0} sati"}},"hour-short":{0:"ovog sata",future:{one:"za {0} č.",few:"za {0} č.",other:"za {0} č."},past:{one:"prije {0} č.",few:"prije {0} č.",other:"prije {0} č."}},"hour-narrow":{0:"ovog sata",future:{one:"za {0} č.",few:"za {0} č.",other:"za {0} č."},past:{one:"prije {0} č.",few:"prije {0} č.",other:"prije {0} č."}},minute:{0:"ovog minuta",future:{one:"za {0} minut",few:"za {0} minuta",other:"za {0} minuta"},past:{one:"prije {0} minuta",few:"prije {0} minuta",other:"prije {0} minuta"}},"minute-short":{0:"ovog minuta",future:{one:"za {0} min.",few:"za {0} min.",other:"za {0} min."},past:{one:"prije {0} min.",few:"prije {0} min.",other:"prije {0} min."}},"minute-narrow":{0:"ovog minuta",future:{one:"za {0} min.",few:"za {0} min.",other:"za {0} min."},past:{one:"prije {0} min.",few:"prije {0} min.",other:"prije {0} min."}},second:{0:"sada",future:{one:"za {0} sekundu",few:"za {0} sekunde",other:"za {0} sekundi"},past:{one:"prije {0} sekunde",few:"prije {0} sekunde",other:"prije {0} sekundi"}},"second-short":{0:"sada",future:{one:"za {0} sek.",few:"za {0} sek.",other:"za {0} sek."},past:{one:"prije {0} sek.",few:"prije {0} sek.",other:"prije {0} sek."}},"second-narrow":{0:"sada",future:{one:"za {0} s.",few:"za {0} s.",other:"za {0} s."},past:{one:"prije {0} s.",few:"prije {0} s.",other:"prije {0} s."}}},locale:"sr-Latn-BA"})}}]);
//# sourceMappingURL=19068.f07cb65ce0230ab5c06e.index.js.map