(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[37461],{37461:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"aurten",1:"hurrengo urtean",future:{one:"{0} urte barru",other:"{0} urte barru"},past:{one:"Duela {0} urte",other:"Duela {0} urte"},"-1":"iaz"},"year-short":{0:"aurten",1:"hurrengo urtea",future:{one:"{0} urte barru",other:"{0} urte barru"},past:{one:"Duela {0} urte",other:"Duela {0} urte"},"-1":"aurreko urtea"},"year-narrow":{0:"aurten",1:"hurrengo urtea",future:{one:"{0} urte barru",other:"{0} urte barru"},past:{one:"Duela {0} urte",other:"Duela {0} urte"},"-1":"aurreko urtea"},quarter:{0:"hiruhileko hau",1:"hurrengo hiruhilekoa",future:{one:"{0} hiruhileko barru",other:"{0} hiruhileko barru"},past:{one:"Duela {0} hiruhileko",other:"Duela {0} hiruhileko"},"-1":"aurreko hiruhilekoa"},"quarter-short":{0:"hiruhileko hau",1:"hurrengo hiruhilekoa",future:{one:"{0} hiruhileko barru",other:"{0} hiruhileko barru"},past:{one:"Duela {0} hiruhileko",other:"Duela {0} hiruhileko"},"-1":"aurreko hiruhilekoa"},"quarter-narrow":{0:"hiruhileko hau",1:"hurrengo hiruhilekoa",future:{one:"{0} hiruhileko barru",other:"{0} hiruhileko barru"},past:{one:"Duela {0} hiruhileko",other:"Duela {0} hiruhileko"},"-1":"aurreko hiruhilekoa"},month:{0:"hilabete honetan",1:"hurrengo hilabetean",future:{one:"{0} hilabete barru",other:"{0} hilabete barru"},past:{one:"Duela {0} hilabete",other:"Duela {0} hilabete"},"-1":"aurreko hilabetean"},"month-short":{0:"hilabete honetan",1:"hurrengo hilabetean",future:{one:"{0} hilabete barru",other:"{0} hilabete barru"},past:{one:"Duela {0} hilabete",other:"Duela {0} hilabete"},"-1":"aurreko hilabetean"},"month-narrow":{0:"hilabete honetan",1:"hurrengo hilabetean",future:{one:"{0} hilabete barru",other:"{0} hilabete barru"},past:{one:"Duela {0} hilabete",other:"Duela {0} hilabete"},"-1":"aurreko hilabetean"},week:{0:"aste honetan",1:"hurrengo astean",future:{one:"{0} aste barru",other:"{0} aste barru"},past:{one:"Duela {0} aste",other:"Duela {0} aste"},"-1":"aurreko astean"},"week-short":{0:"aste honetan",1:"hurrengo astean",future:{one:"{0} aste barru",other:"{0} aste barru"},past:{one:"Duela {0} aste",other:"Duela {0} aste"},"-1":"aurreko astean"},"week-narrow":{0:"aste honetan",1:"hurrengo astean",future:{one:"{0} aste barru",other:"{0} aste barru"},past:{one:"Duela {0} aste",other:"Duela {0} aste"},"-1":"aurreko astean"},day:{0:"gaur",1:"bihar",2:"etzi",future:{one:"{0} egun barru",other:"{0} egun barru"},past:{one:"Duela {0} egun",other:"Duela {0} egun"},"-2":"herenegun","-1":"atzo"},"day-short":{0:"gaur",1:"bihar",2:"etzi",future:{one:"{0} egun barru",other:"{0} egun barru"},past:{one:"Duela {0} egun",other:"Duela {0} egun"},"-2":"herenegun","-1":"atzo"},"day-narrow":{0:"gaur",1:"bihar",2:"etzi",future:{one:"{0} egun barru",other:"{0} egun barru"},past:{one:"Duela {0} egun",other:"Duela {0} egun"},"-2":"herenegun","-1":"atzo"},hour:{0:"ordu honetan",future:{one:"{0} ordu barru",other:"{0} ordu barru"},past:{one:"Duela {0} ordu",other:"Duela {0} ordu"}},"hour-short":{0:"ordu honetan",future:{one:"{0} ordu barru",other:"{0} ordu barru"},past:{one:"Duela {0} ordu",other:"Duela {0} ordu"}},"hour-narrow":{0:"ordu honetan",future:{one:"{0} ordu barru",other:"{0} ordu barru"},past:{one:"Duela {0} ordu",other:"Duela {0} ordu"}},minute:{0:"minutu honetan",future:{one:"{0} minutu barru",other:"{0} minutu barru"},past:{one:"Duela {0} minutu",other:"Duela {0} minutu"}},"minute-short":{0:"minutu honetan",future:{one:"{0} minutu barru",other:"{0} minutu barru"},past:{one:"Duela {0} minutu",other:"Duela {0} minutu"}},"minute-narrow":{0:"minutu honetan",future:{one:"{0} minutu barru",other:"{0} minutu barru"},past:{one:"Duela {0} minutu",other:"Duela {0} minutu"}},second:{0:"orain",future:{one:"{0} segundo barru",other:"{0} segundo barru"},past:{one:"Duela {0} segundo",other:"Duela {0} segundo"}},"second-short":{0:"orain",future:{one:"{0} segundo barru",other:"{0} segundo barru"},past:{one:"Duela {0} segundo",other:"Duela {0} segundo"}},"second-narrow":{0:"orain",future:{one:"{0} segundo barru",other:"{0} segundo barru"},past:{one:"Duela {0} segundo",other:"Duela {0} segundo"}}},locale:"eu"})}}]);
//# sourceMappingURL=37461.f07cb65ce0230ab5c06e.index.js.map