# Generated by Django 3.1.4 on 2020-12-16 08:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("courses", "0024_auto_20201216_0740"),
    ]

    operations = [
        migrations.AlterField(
            model_name="courseruntranslation",
            name="title",
            field=models.CharField(
                blank=True, max_length=255, null=True, verbose_name="title"
            ),
        ),
    ]
